package com.jjoe64.graphviewdemos;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import android.app.Activity;
import android.graphics.Color;
import android.graphics.Paint.Align;
import android.os.Bundle;
import android.widget.LinearLayout;

import com.jjoe64.graphview.CustomLabelFormatter;
import com.jjoe64.graphview.GraphView;
import com.jjoe64.graphview.GraphView.GraphViewData;
import com.jjoe64.graphview.GraphViewSeries;
import com.jjoe64.graphview.GraphViewSeries.GraphViewSeriesStyle;
import com.jjoe64.graphview.LineGraphView;

public class ChartActivity extends Activity {


  @Override
  protected void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    setContentView(R.layout.line_chart);
    initLineChartView();
    initLineChartView2();
  }

  private void initLineChartView2() {
    // init example series data
    long now = new Date().getTime();
    long t = 86400000;

    GraphViewSeries exampleSeries =
        new GraphViewSeries("", new GraphViewSeriesStyle(Color.rgb(250, 98, 65), 2),
            new GraphViewData[] {new GraphViewData(now - 6 * t, 2.2d),
                new GraphViewData(now - 5 * t, 2.0d),
                new GraphViewData(now - 4 * t, 1.5d),
                new GraphViewData(now - 3 * t, 3.0d) // another frequency
                , new GraphViewData(now - 2 * t, 2.5d), new GraphViewData(now - 1 * t, 1.0d),
                new GraphViewData(now, 3.0d)});

    // graph with dynamically genereated horizontal and vertical labels
    GraphView graphView;
    graphView = new LineGraphView(this // context
        , "" // heading
    );
    ((LineGraphView) graphView).setDrawBackground(true);
    // ((LineGraphView) graphView).setDrawDataPoints(true);
    // ((LineGraphView) graphView).setDataPointsRadius(15f);
    ((LineGraphView) graphView).setBackgroundColor(Color.argb(128, 254, 232, 226));
    ((LineGraphView) graphView).setDataPointsRadius(0);

    int fontColor = Color.parseColor("#9B9A9B");
    graphView.getGraphViewStyle().setGridColor(Color.parseColor("#EEEEEE"));
    graphView.getGraphViewStyle().setHorizontalLabelsColor(fontColor);
    graphView.getGraphViewStyle().setVerticalLabelsColor(fontColor);
    graphView.getGraphViewStyle().setNumHorizontalLabels(7);
    graphView.getGraphViewStyle().setNumVerticalLabels(4);
    graphView.getGraphViewStyle().setTextSize(12);
    graphView.getGraphViewStyle().setVerticalLabelsAlign(Align.RIGHT);
    graphView.getGraphViewStyle().setVerticalLabelsWidth(30);

    graphView.addSeries(exampleSeries); // data

    final SimpleDateFormat dateFormat = new SimpleDateFormat("MM-dd", Locale.CHINESE);
    graphView.setCustomLabelFormatter(new CustomLabelFormatter() {
      @Override
      public String formatLabel(double value, boolean isValueX) {
        if (isValueX) {
          Date d = new Date((long) value);
          return dateFormat.format(d);
        }
        return null; // let graphview generate Y-axis label for us
      }
    });


    LinearLayout layout = (LinearLayout) findViewById(R.id.line_chart);
    layout.addView(graphView);
  }

  private void initLineChartView() {
    long now = new Date().getTime();
    long t = 86400000;

    GraphViewSeries exampleSeries =
        new GraphViewSeries("", new GraphViewSeriesStyle(Color.rgb(250, 98, 65), 2),
            new GraphViewData[] {new GraphViewData(now - 6 * t, 0),
                new GraphViewData(now - 5 * t, 10d), new GraphViewData(now - 4 * t, 23d),
                new GraphViewData(now - 3 * t, 49d), new GraphViewData(now - 2 * t, 68d),
                new GraphViewData(now - 1 * t, 120d), new GraphViewData(now, 94d)});

    GraphView graphView;
    graphView = new LineGraphView(this, "");
    ((LineGraphView) graphView).setDrawBackground(true);
    // 线条色
    ((LineGraphView) graphView).setBackgroundColor(Color.argb(128, 254, 232, 226));
    ((LineGraphView) graphView).setDataPointsRadius(0);

    // 字体色
    int fontColor = Color.parseColor("#9B9A9B");
    // 风格色
    graphView.getGraphViewStyle().setGridColor(Color.parseColor("#EEEEEE"));
    graphView.getGraphViewStyle().setHorizontalLabelsColor(fontColor);
    graphView.getGraphViewStyle().setVerticalLabelsColor(fontColor);
    // x轴标签数
    graphView.getGraphViewStyle().setNumHorizontalLabels(7);
    // y轴标签数
    graphView.getGraphViewStyle().setNumVerticalLabels(4);
    // 字号
    graphView.getGraphViewStyle().setTextSize(12);
    graphView.getGraphViewStyle().setVerticalLabelsAlign(Align.RIGHT);
    graphView.getGraphViewStyle().setVerticalLabelsWidth(20);

    graphView.addSeries(exampleSeries);

    final SimpleDateFormat dateFormat = new SimpleDateFormat("MM-dd", Locale.CHINESE);
    graphView.setCustomLabelFormatter(new CustomLabelFormatter() {
      @Override
      public String formatLabel(double value, boolean isValueX) {
        if (isValueX) {
          Date d = new Date((long) value);
          return dateFormat.format(d);
        }
        return null;
      }
    });


    LinearLayout layout = (LinearLayout) findViewById(R.id.line_chart);
    layout.addView(graphView);
  }



}
